========
URICache
========


.. image:: https://img.shields.io/pypi/v/uricache.svg
        :target: https://pypi.python.org/pypi/uricache

.. image:: https://img.shields.io/travis/unodan/uricache.svg
        :target: https://travis-ci.org/unodan/uricache

.. image:: https://readthedocs.org/projects/uricache/badge/?version=latest
        :target: https://uricache.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status




URICache is a caching module that stores data in JSON format, using URI's for accessing the cache.


* Free software: MIT license
* Documentation: https://uricache.readthedocs.io.


Features
--------

* TODO

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
